==> nextcloud-app-calendar-1%3A3.0.2-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/calendar/l10n/id.js <==
OC.L10N.register(
    "calendar",
    {
    "Provided email-address is not valid" : "Alamat surel tidak valid",
    "%s has published the calendar »%s«" : "%s telah mempublikasikan kalender »%s«",
    "Unexpected error sending email. Please contact your administrator." : "Galat saat mengirim surel. Silakan hubungi administrator Anda.",
    "Hello," : "Halo,",
    "We wanted to inform you that %s has published the calendar »%s«." : "Kami ingin menginformasikan anda bahwa %s telah mempublikasikan kalender »%s«.",
    "Open »%s«" : "Buka »%s«",
    "Cheers!" : "Horee!",
    "Calendar" : "Kalender",
    "A Calendar app for Nextcloud" : "Aplikasi Kalender untuk Nextcloud",
    "Previous day" : "Hari sebelum",
    "Previous week" : "Minggu sebelum",
    "Previous month" : "Bulan sebelum",
    "Next day" : "Hari setelah",
    "Next week" : "Minggu setelah",
    "Next month" : "Bulan setelah",
    "+ New event" : "+ Acara baru",
    "Today" : "Hari Ini",
    "Day" : "Hari",
    "Week" : "Minggu",
    "Month" : "Bulan",
    "Delete" : "Hapus",
    "Untitled calendar" : "Kalender tanpa judul",
    "Edit name" : "Edit nama",
    "Saving name …" : "Menyimpan nama …",
    "Edit color" : "Edit warna",
    "Saving color …" : "Menyimpan warna …",
    "Copy private link" : "Salin tautan privat",
    "Download" : "Unduh",
    "An error occurred, unable to change visibility of the calendar." : "Terjadi galat, tidak dapat mengubah visibilitas kalender.",
    "An error occurred, unable to delete the calendar." : "Terjadi galat, tidak dapat menghapus kalender.",
    "Calendar link copied to clipboard." : "Tautan kalender disalin ke papan klip.",
    "Calendar link could not be copied to clipboard." : "Tautan kalender tidak dapat disalin ke papan klip.",
    "An error occurred, unable to rename the calendar." : "Terjadi galat, tidak dapat mengubah nama kalender.",
    "An error occurred, unable to change the calendar's color." : "Terjadi galat, tidak dapat mengganti warna kalender.",
    "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["Batal berbagi kalender dalam {countdown} detik"],
    "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["Menghapus kalender dalam {countdown} detik"],
    "Share link" : "Bagi tautan",
    "Publish calendar" : "Menerbitkan kalender",
    "Publishing calendar" : "Menerbitkan kalender",
    "Copy public link" : "Salin tautan publik",
    "Send link to calendar via email" : "Kirim tautan kalender via surel",
    "Sending email …" : "Mengirim surel …",
    "Copy subscription link" : "Salin tautan berlangganan",
    "Copying link …" : "Menyalin tautan …",
    "Copied link" : "Tautan tersalin",
    "Could not copy link" : "Tidak dapat menyalin tautan",
    "Copy embedding code" : "Salin kode penyemat",
    "Copying code …" : "Menyalin kode …",
    "Copied code" : "Kode tersalin",
    "Could not copy code" : "Tidak dapat menyalin kode",
    "Delete share link" : "Hapus tautan berbagi",
    "Deleting share link …" : "Menghapus tautan berbagi …",
    "An error occurred, unable to publish calendar." : "Terjadi galat, tidak dapat menerbitkan kalender.",
    "An error occurred, unable to send email." : "Terjadi galat, tidak dapat mengirim surel.",
    "Embed code copied to clipboard." : "Kode tersemat disalin ke papan klip",
    "Embed code could not be copied to clipboard." : "Kode tersemat tidak dapat disalin ke papan klip.",
    "Unpublishing calendar failed" : "Gagal membatalkan penerbitan kalender",
    "Share with users or groups" : "Berbagi dengan pengguna atau grup",
    "No users or groups" : "Tidak ada pengguna atau grup",
    "can edit" : "dapat edit",
    "Unshare with {displayName}" : "Batal berbagi dengan {displayName}",
    "An error occurred, unable to change the unshare the calendar." : "Terjadi galat, tidak dapat mengubah pembatalan berbagi kalender.",
    "An error occurred, unable to change the permission of the share." : "Terjadi galat, tidak dapat mengubah hak akses berbagi.",
    "+ New calendar" : "+ Kalender baru",
    "New calendar" : "Kalender baru",
    "Creating calendar …" : "Membuat kalender …",
    "New calendar with task list" : "Kalender baru dengan daftar tugas",
    "New subscription from link (read-only)" : "Langganan baru dengan tautan (baca-saja)",
    "Creating subscription …" : "Membuat langganan …",
    "An error occurred, unable to create the calendar." : "Terjadi galat, tidak dapat membuat kalender.",
    "Please enter a valid link (starting with http://, https://, webcal://, or webcals://)" : "Silakan isi tautan valid (dimulai dengan http://, https://, webcal://, or webcals://)",
    "Import calendars" : "Impor kalender",
    "Filename" : "Nama berkas",
    "Cancel" : "Batal",
    "_Import calendar_::_Import calendars_" : ["Impor kalender"],
    "No valid files found, aborting import" : "Berkas valid tidak ditemukan, impor dibatalkan",
    "Import partially failed. Imported {accepted} out of {total}." : "Sebagian impor gagal. Dari {total} hanya {accepted} berhasil impor.",
    "_Successfully imported %n event_::_Successfully imported %n events._" : ["Berhasil impor %n acara."],
    "Automatic" : "Otomatis",
    "Automatic ({detected})" : "Otomatis ({detected})",
    "New setting was not saved successfully." : "Setelan baru tidak berhasil tersimpan.",
    "Shortcut overview" : "Ikhtisar pintasan",
    "or" : "atau",
    "Navigation" : "Navigasi",
    "Previous period" : "Periode sebelum",
    "Next period" : "Periode sesudah",
    "Views" : "Tampilan",
    "Day view" : "Tampilan hari",
    "Week view" : "Tampilan minggu",
    "Month view" : "Tampilan bulan",
    "Actions" : "Tindakan",
    "Create event" : "Buat acara",
    "Show shortcuts" : "Tampilkan pintasan",
    "Enable birthday calendar" : "Aktifkan kalender ulang tahun",
    "Show tasks in calendar" : "Tampilkan tugas dalam kalender",
    "Enable simplified editor" : "Aktifkan editor serderhana",
    "Limit visible events per view" : "Batasi acara terlihat per tampilan",
    "Show weekends" : "Tampilkan akhir pekan",
    "Show week numbers" : "Tampilkan nomor pekan",
    "Copy primary CalDAV address" : "Salin alamat utama CalDAV",
    "Copy iOS/macOS CalDAV address" : "Salin alamat CalDAV iOS/macOS",
    "Show keyboard shortcuts" : "Tampilkan pintasan papan kunci",
    "Settings & import" : "Setelan & impor",
    "CalDAV link copied to clipboard." : "Tautan CalDAV disalin ke papan klip",
    "CalDAV link could not be copied to clipboard." : "Tautan CalDAV tidak dapat disalin ke papan klip",
    "Location" : "Lokasi",
    "Description" : "Deskrisi",
    "Monday" : "Senin",
    "Save" : "Simpan",
    "Update" : "Perbarui",
    "Notification" : "Notifikasi",
    "Email" : "Surel",
    "Audio notification" : "Notifikasi audio",
    "Other notification" : "Notifikasi lain",
    "Relative to event" : "Relatif terhadap acara",
    "On date" : "Pada tanggal",
    "Edit time" : "Edit waktu",
    "Save time" : "Simpan waktu",
    "Remove reminder" : "Buang pengingat",
    "on" : "pada",
    "at" : "di",
    "+ Add reminder" : "+ Tambah pengingat",
    "_second_::_seconds_" : ["detik"],
    "_minute_::_minutes_" : ["menit"],
    "_hour_::_hours_" : ["jam"],
    "_day_::_days_" : ["hari"],
    "_week_::_weeks_" : ["minggu"],
    "Availability of attendees, resources and rooms" : "Ketersediaan peserta, sumber daya, dan ruangan",
    "Free" : "Luang",
    "Busy (tentative)" : "Sibuk (tentatif)",
    "Busy" : "Sibuk",
    "Out of office" : "Keluar kantor",
    "Unknown" : "Tidak diketahui",
    "Create Talk room for this event" : "Buat ruangan Talk untuk acara ini",
    "Show busy times" : "Tampilkan waktu sibuk",
    "No attendees yet" : "Belum ada peserta",
    "Successfully appended link to talk room to description." : "Berhasil menambahkan tautan ruang Talk pada deskripsi.",
    "Error creating Talk room" : "Galat membuat ruangan Talk",
    "Required participant" : "Partisipan wajib",
    "Optional participant" : "Partisipan opsional",
    "Non-participant" : "Bukan partisipan",
    "Remove attendee" : "Hapus peserta",
    "No match found" : "Tidak ditemukan kecocokan",
    "(organizer)" : "(penyelenggara)",
    "Remove color" : "Hapus warna",
    "Event title" : "Judul acara",
    "All day" : "Sepanjang hari",
    "Repeat" : "Ulang",
    "End repeat" : "Akhiri perulangan",
    "Select to end repeat" : "Pilih untuk mengakhiri perulangan",
    "never" : "tidak pernah",
    "on date" : "pada tanggal",
    "after" : "setelah",
    "first" : "pertama",
    "third" : "ke-3",
    "fourth" : "ke-4",
    "fifth" : "ke-5",
    "second to last" : "kedua terakhir",
    "last" : "terakhir",
    "Repeat every" : "Ulang setiap",
    "By day of the month" : "Berdasarkan hari pada bulan",
    "On the" : "Pada",
    "_month_::_months_" : ["bulang"],
    "_year_::_years_" : ["tahun"],
    "weekday" : "akhir pekan",
    "weekend day" : "akhir pekan",
    "The recurrence definition of this event is not fully supported by Nextcloud. If you edit the recurrence-options, certain recurrences may be lost." : "Penentuan perulangan acara ini tidak sepenuhnya didukung oleh Nextcloud. Jika Anda mengedit opsi pengulangan, pengulangan tertentu mungkin hilang.",
    "More" : "Lainnya",
    "Public calendar does not exist" : "Kalender publik tidak eksis",
    "Maybe the share was deleted or has expired?" : "Mungkin yang dibagikan terhapus atau kadaluwarsa?",
    "Pick a time" : "Pilih waktu",
    "Pick a date" : "Pilih tanggal",
    "Please enter a valid date" : "Silakan isi tanggal valid",
    "Please enter a valid date and time" : "Silakan isi tanggal dan waktu valid",
    "Personal" : "Pribadi",
    "Details" : "Detail",
    "Attendees" : "Peserta",
    "Close" : "Tutup",
    "Show more details" : "Tampilkan detail lain",
    "Subscribe to {name}" : "Berlangganan ke {name}",
    "Download {name}" : "Unduh {name}",
    "Anniversary" : "Hari jadi",
    "Appointment" : "Janji",
    "Business" : "Bisnis",
    "Education" : "Edukasi",
    "Holiday" : "Hari raya",
    "Meeting" : "Rapat",
    "Miscellaneous" : "Lain-lain",
    "Non-working hours" : "Luar waktu kerja",
    "Not in office" : "Tidak ada di kantor",
    "Phone call" : "Panggilan telepon",
    "Sick day" : "Hari sakit",
    "Special occasion" : "Acara khusus",
    "Travel" : "Perjalanan",
    "Vacation" : "Liburan",
    "Midnight on the day the event starts" : "Tengah malam pada hari acara dimulai",
    "_%n day before the event at {formattedHourMinute}_::_%n days before the event at {formattedHourMinute}_" : ["%n hari sebelum acara {formattedHourMinute}"],
    "_%n week before the event at {formattedHourMinute}_::_%n weeks before the event at {formattedHourMinute}_" : ["%n pekan sebelum acara {formattedHourMinute}"],
    "on the day of the event at {formattedHourMinute}" : "Pada hari acara {formattedHourMinute}",
    "at the event's start" : "pada awal acara",
    "at the event's end" : "pada akhir acara",
    "{time} before the event starts" : "{time} sebelum acara berlangsung",
    "{time} before the event ends" : "{time} sebelum acara berakhir",
    "{time} after the event starts" : "{time} setelah acara berlangsung",
    "{time} after the event ends" : "{time} setelah acara berakhir",
    "on {time}" : "pada {time}",
    "on {time} ({timezoneId})" : "pada {time} ({timezoneId})",
    "Week {number} of {year}" : "Pekan {number} tahun {year}",
    "Daily" : "Harian",
    "Weekly" : "Mingguan",
    "Monthly" : "Bulanan",
    "Yearly" : "Tahunan",
    "_Every %n day_::_Every %n days_" : ["Setiap %n hari"],
    "_Every %n week_::_Every %n weeks_" : ["Setiap %n pekan"],
    "_Every %n month_::_Every %n months_" : ["Setiap %n bulan"],
    "_Every %n year_::_Every %n years_" : ["Setiap %n tahun"],
    "_on {weekday}_::_on {weekdays}_" : ["pada {weekdays}"],
    "_on day {dayOfMonthList}_::_on days {dayOfMonthList}_" : ["pada hari {dayOfMonthList}"],
    "until {untilDate}" : "sampai {untilDate}",
    "_%n time_::_%n times_" : ["%n kali"],
    "Untitled event" : "Acara tanpa judul",
    "Untitled task" : "Tugas tanpa judul",
    "Please ask your administrator to enable the Tasks App." : "Silakan tanya administrator Anda untuk mengaktifkan aplikasi Tugas.",
    "_+%n more_::_+%n more_" : ["+%n lagi"],
    "Add a location" : "Tambah lokasi",
    "Add a description" : "Tambah deskripsi",
    "Status" : "Status",
    "Confirmed" : "Terkonfirmasi",
    "Tentative" : "Tentatif",
    "Confirmation about the overall status of the event." : "Konfirmasi tentang status keseluruhan acara.",
    "Show as" : "Tampilkan sebagai",
    "Take this event into account when calculating free-busy information." : "Pertimbangkan acara ini saat perhitungan waktu luang dan sibuk.",
    "Categories" : "Kategori",
    "Categories help you to structure and organize your events." : "Kategori membantu Anda menyusun dan mengatur acara.",
    "Search or add categories" : "Cari atau tambah kategori",
    "Add this as a new category" : "Tambah sebagai kategori baru",
    "Custom color" : "Warna khusus",
    "Special color of this event. Overrides the calendar-color." : "Warna spesial dari acara ini. Mengganti warna kalender.",
    "Chat room for event" : "Ruang obrolan untuk acara"
},
"nplurals=1; plural=0;");

==> nextcloud-app-calendar-1%3A3.3.0-3-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/calendar/l10n/id.js <==
OC.L10N.register(
    "calendar",
    {
    "Provided email-address is not valid" : "Alamat surel tidak valid",
    "%s has published the calendar »%s«" : "%s telah mempublikasikan kalender »%s«",
    "Unexpected error sending email. Please contact your administrator." : "Galat saat mengirim surel. Silakan hubungi administrator Anda.",
    "Hello," : "Halo,",
    "We wanted to inform you that %s has published the calendar »%s«." : "Kami ingin menginformasikan anda bahwa %s telah mempublikasikan kalender »%s«.",
    "Open »%s«" : "Buka »%s«",
    "Cheers!" : "Horee!",
    "Confirm" : "Konfirmasi",
    "Calendar" : "Kalender",
    "A Calendar app for Nextcloud" : "Aplikasi Kalender untuk Nextcloud",
    "Previous day" : "Hari sebelum",
    "Previous week" : "Minggu sebelum",
    "Previous month" : "Bulan sebelum",
    "Next day" : "Hari setelah",
    "Next week" : "Minggu setelah",
    "Next month" : "Bulan setelah",
    "Today" : "Hari Ini",
    "Day" : "Hari",
    "Week" : "Minggu",
    "Month" : "Bulan",
    "Preview" : "Pratinjau",
    "Copy link" : "Salin tautan",
    "Edit" : "Sunting",
    "Delete" : "Hapus",
    "Untitled calendar" : "Kalender tanpa judul",
    "Edit name" : "Edit nama",
    "Saving name …" : "Menyimpan nama …",
    "Edit color" : "Edit warna",
    "Saving color …" : "Menyimpan warna …",
    "Copy private link" : "Salin tautan privat",
    "Export" : "Ekspor",
    "An error occurred, unable to change visibility of the calendar." : "Terjadi galat, tidak dapat mengubah visibilitas kalender.",
    "An error occurred, unable to delete the calendar." : "Terjadi galat, tidak dapat menghapus kalender.",
    "Calendar link copied to clipboard." : "Tautan kalender disalin ke papan klip.",
    "Calendar link could not be copied to clipboard." : "Tautan kalender tidak dapat disalin ke papan klip.",
    "An error occurred, unable to rename the calendar." : "Terjadi galat, tidak dapat mengubah nama kalender.",
    "An error occurred, unable to change the calendar's color." : "Terjadi galat, tidak dapat mengganti warna kalender.",
    "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["Batal berbagi kalender dalam {countdown} detik"],
    "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["Menghapus kalender dalam {countdown} detik"],
    "Share link" : "Bagi tautan",
    "Publish calendar" : "Menerbitkan kalender",
    "Publishing calendar" : "Menerbitkan kalender",
    "Copy public link" : "Salin tautan publik",
    "Send link to calendar via email" : "Kirim tautan kalender via surel",
    "Sending email …" : "Mengirim surel …",
    "Copy subscription link" : "Salin tautan berlangganan",
    "Copying link …" : "Menyalin tautan …",
    "Copied link" : "Tautan tersalin",
    "Could not copy link" : "Tidak dapat menyalin tautan",
    "Copy embedding code" : "Salin kode penyemat",
    "Copying code …" : "Menyalin kode …",
    "Copied code" : "Kode tersalin",
    "Could not copy code" : "Tidak dapat menyalin kode",
    "Delete share link" : "Hapus tautan berbagi",
    "Deleting share link …" : "Menghapus tautan berbagi …",
    "An error occurred, unable to publish calendar." : "Terjadi galat, tidak dapat menerbitkan kalender.",
    "An error occurred, unable to send email." : "Terjadi galat, tidak dapat mengirim surel.",
    "Embed code copied to clipboard." : "Kode tersemat disalin ke papan klip",
    "Embed code could not be copied to clipboard." : "Kode tersemat tidak dapat disalin ke papan klip.",
    "Unpublishing calendar failed" : "Gagal membatalkan penerbitan kalender",
    "Share with users or groups" : "Berbagi dengan pengguna atau grup",
    "No users or groups" : "Tidak ada pengguna atau grup",
    "can edit" : "dapat edit",
    "Unshare with {displayName}" : "Batal berbagi dengan {displayName}",
    "An error occurred, unable to change the unshare the calendar." : "Terjadi galat, tidak dapat mengubah pembatalan berbagi kalender.",
    "An error occurred, unable to change the permission of the share." : "Terjadi galat, tidak dapat mengubah hak akses berbagi.",
    "+ New calendar" : "+ Kalender baru",
    "New calendar" : "Kalender baru",
    "Creating calendar …" : "Membuat kalender …",
    "New calendar with task list" : "Kalender baru dengan daftar tugas",
    "New subscription from link (read-only)" : "Langganan baru dengan tautan (baca-saja)",
    "Creating subscription …" : "Membuat langganan …",
    "An error occurred, unable to create the calendar." : "Terjadi galat, tidak dapat membuat kalender.",
    "Please enter a valid link (starting with http://, https://, webcal://, or webcals://)" : "Silakan isi tautan valid (dimulai dengan http://, https://, webcal://, or webcals://)",
    "Name" : "Nama",
    "Deleted" : "Dihapus",
    "Restore" : "Pulihkan",
    "Delete permanently" : "Hapus secara permanen",
    "Empty trash bin" : "Kosongkan tempat sampah",
    "Import calendars" : "Impor kalender",
    "Filename" : "Nama berkas",
    "Cancel" : "Batal",
    "_Import calendar_::_Import calendars_" : ["Impor kalender"],
    "No valid files found, aborting import" : "Berkas valid tidak ditemukan, impor dibatalkan",
    "Import partially failed. Imported {accepted} out of {total}." : "Sebagian impor gagal. Dari {total} hanya {accepted} berhasil impor.",
    "Automatic" : "Otomatis",
    "Automatic ({detected})" : "Otomatis ({detected})",
    "New setting was not saved successfully." : "Setelan baru tidak berhasil tersimpan.",
    "Shortcut overview" : "Ikhtisar pintasan",
    "or" : "atau",
    "Navigation" : "Navigasi",
    "Previous period" : "Periode sebelum",
    "Next period" : "Periode sesudah",
    "Views" : "Tampilan",
    "Day view" : "Tampilan hari",
    "Week view" : "Tampilan minggu",
    "Month view" : "Tampilan bulan",
    "List view" : "Tampilan lis",
    "Actions" : "Tindakan",
    "Create event" : "Buat acara",
    "Show shortcuts" : "Tampilkan pintasan",
    "Enable birthday calendar" : "Aktifkan kalender ulang tahun",
    "Show tasks in calendar" : "Tampilkan tugas dalam kalender",
    "Enable simplified editor" : "Aktifkan editor serderhana",
    "Limit visible events per view" : "Batasi acara terlihat per tampilan",
    "Show weekends" : "Tampilkan akhir pekan",
    "Show week numbers" : "Tampilkan nomor pekan",
    "Copy primary CalDAV address" : "Salin alamat utama CalDAV",
    "Copy iOS/macOS CalDAV address" : "Salin alamat CalDAV iOS/macOS",
    "Show keyboard shortcuts" : "Tampilkan pintasan papan kunci",
    "Settings & import" : "Setelan & impor",
    "CalDAV link copied to clipboard." : "Tautan CalDAV disalin ke papan klip",
    "CalDAV link could not be copied to clipboard." : "Tautan CalDAV tidak dapat disalin ke papan klip",
    "Location" : "Lokasi",
    "Description" : "Deskrisi",
    "to" : "untuk",
    "Add" : "Masukkan",
    "Monday" : "Senin",
    "Tuesday" : "Selasa",
    "Wednesday" : "Rabu",
    "Thursday" : "Kamis",
    "Friday" : "Jumat",
    "Saturday" : "Sabtu",
    "Sunday" : "Minggu",
    "Save" : "Simpan",
    "Update" : "Perbarui",
    "Your email address" : "Alamat surel Anda",
    "Notification" : "Notifikasi",
    "Email" : "Surel",
    "Audio notification" : "Notifikasi audio",
    "Other notification" : "Notifikasi lain",
    "Relative to event" : "Relatif terhadap acara",
    "On date" : "Pada tanggal",
    "Edit time" : "Edit waktu",
    "Save time" : "Simpan waktu",
    "Remove reminder" : "Buang pengingat",
    "on" : "pada",
    "at" : "di",
    "+ Add reminder" : "+ Tambah pengingat",
    "_second_::_seconds_" : ["detik"],
    "_minute_::_minutes_" : ["menit"],
    "_hour_::_hours_" : ["jam"],
    "_day_::_days_" : ["hari"],
    "_week_::_weeks_" : ["minggu"],
    "Availability of attendees, resources and rooms" : "Ketersediaan peserta, sumber daya, dan ruangan",
    "Free" : "Luang",
    "Busy (tentative)" : "Sibuk (tentatif)",
    "Busy" : "Sibuk",
    "Out of office" : "Keluar kantor",
    "Unknown" : "Tidak diketahui",
    "Accept" : "Terima",
    "Decline" : "Tolak",
    "Tentative" : "Tentatif",
    "Create Talk room for this event" : "Buat ruangan Talk untuk acara ini",
    "Show busy times" : "Tampilkan waktu sibuk",
    "No attendees yet" : "Belum ada peserta",
    "Successfully appended link to talk room to description." : "Berhasil menambahkan tautan ruang Talk pada deskripsi.",
    "Error creating Talk room" : "Galat membuat ruangan Talk",
    "Send email" : "Kirim surel",
    "Required participant" : "Partisipan wajib",
    "Optional participant" : "Partisipan opsional",
    "Non-participant" : "Bukan partisipan",
    "Remove attendee" : "Hapus peserta",
    "No match found" : "Tidak ditemukan kecocokan",
    "(organizer)" : "(penyelenggara)",
    "Remove color" : "Hapus warna",
    "Event title" : "Judul acara",
    "All day" : "Sepanjang hari",
    "Repeat" : "Ulang",
    "End repeat" : "Akhiri perulangan",
    "Select to end repeat" : "Pilih untuk mengakhiri perulangan",
    "never" : "tidak pernah",
    "on date" : "pada tanggal",
    "after" : "setelah",
    "first" : "pertama",
    "third" : "ke-3",
    "fourth" : "ke-4",
    "fifth" : "ke-5",
    "second to last" : "kedua terakhir",
    "last" : "terakhir",
    "Repeat every" : "Ulang setiap",
    "By day of the month" : "Berdasarkan hari pada bulan",
    "On the" : "Pada",
    "_month_::_months_" : ["bulang"],
    "_year_::_years_" : ["tahun"],
    "weekday" : "akhir pekan",
    "weekend day" : "akhir pekan",
    "The recurrence definition of this event is not fully supported by Nextcloud. If you edit the recurrence-options, certain recurrences may be lost." : "Penentuan perulangan acara ini tidak sepenuhnya didukung oleh Nextcloud. Jika Anda mengedit opsi pengulangan, pengulangan tertentu mungkin hilang.",
    "More" : "Lainnya",
    "Public calendar does not exist" : "Kalender publik tidak eksis",
    "Maybe the share was deleted or has expired?" : "Mungkin yang dibagikan terhapus atau kadaluwarsa?",
    "Pick a time" : "Pilih waktu",
    "Pick a date" : "Pilih tanggal",
    "Please enter a valid date" : "Silakan isi tanggal valid",
    "Please enter a valid date and time" : "Silakan isi tanggal dan waktu valid",
    "Personal" : "Pribadi",
    "Details" : "Detail",
    "Attendees" : "Peserta",
    "Close" : "Tutup",
    "Show more details" : "Tampilkan detail lain",
    "Subscribe to {name}" : "Berlangganan ke {name}",
    "Anniversary" : "Hari jadi",
    "Appointment" : "Janji",
    "Business" : "Bisnis",
    "Education" : "Edukasi",
    "Holiday" : "Hari raya",
    "Meeting" : "Rapat",
    "Miscellaneous" : "Lain-lain",
    "Non-working hours" : "Luar waktu kerja",
    "Not in office" : "Tidak ada di kantor",
    "Phone call" : "Panggilan telepon",
    "Sick day" : "Hari sakit",
    "Special occasion" : "Acara khusus",
    "Travel" : "Perjalanan",
    "Vacation" : "Liburan",
    "Midnight on the day the event starts" : "Tengah malam pada hari acara dimulai",
    "_%n day before the event at {formattedHourMinute}_::_%n days before the event at {formattedHourMinute}_" : ["%n hari sebelum acara {formattedHourMinute}"],
    "_%n week before the event at {formattedHourMinute}_::_%n weeks before the event at {formattedHourMinute}_" : ["%n pekan sebelum acara {formattedHourMinute}"],
    "on the day of the event at {formattedHourMinute}" : "Pada hari acara {formattedHourMinute}",
    "at the event's start" : "pada awal acara",
    "at the event's end" : "pada akhir acara",
    "{time} before the event starts" : "{time} sebelum acara berlangsung",
    "{time} before the event ends" : "{time} sebelum acara berakhir",
    "{time} after the event starts" : "{time} setelah acara berlangsung",
    "{time} after the event ends" : "{time} setelah acara berakhir",
    "on {time}" : "pada {time}",
    "on {time} ({timezoneId})" : "pada {time} ({timezoneId})",
    "Week {number} of {year}" : "Pekan {number} tahun {year}",
    "Daily" : "Harian",
    "Weekly" : "Mingguan",
    "Monthly" : "Bulanan",
    "Yearly" : "Tahunan",
    "_Every %n day_::_Every %n days_" : ["Setiap %n hari"],
    "_Every %n week_::_Every %n weeks_" : ["Setiap %n pekan"],
    "_Every %n month_::_Every %n months_" : ["Setiap %n bulan"],
    "_Every %n year_::_Every %n years_" : ["Setiap %n tahun"],
    "_on {weekday}_::_on {weekdays}_" : ["pada {weekdays}"],
    "_on day {dayOfMonthList}_::_on days {dayOfMonthList}_" : ["pada hari {dayOfMonthList}"],
    "until {untilDate}" : "sampai {untilDate}",
    "_%n time_::_%n times_" : ["%n kali"],
    "Untitled event" : "Acara tanpa judul",
    "Untitled task" : "Tugas tanpa judul",
    "Please ask your administrator to enable the Tasks App." : "Silakan tanya administrator Anda untuk mengaktifkan aplikasi Tugas.",
    "Next" : "Berikutnya",
    "_+%n more_::_+%n more_" : ["+%n lagi"],
    "Other" : "Lainnya",
    "Add a location" : "Tambah lokasi",
    "Add a description" : "Tambah deskripsi",
    "Status" : "Status",
    "Confirmed" : "Terkonfirmasi",
    "Confirmation about the overall status of the event." : "Konfirmasi tentang status keseluruhan acara.",
    "Show as" : "Tampilkan sebagai",
    "Take this event into account when calculating free-busy information." : "Pertimbangkan acara ini saat perhitungan waktu luang dan sibuk.",
    "Categories" : "Kategori",
    "Categories help you to structure and organize your events." : "Kategori membantu Anda menyusun dan mengatur acara.",
    "Search or add categories" : "Cari atau tambah kategori",
    "Add this as a new category" : "Tambah sebagai kategori baru",
    "Custom color" : "Warna khusus",
    "Special color of this event. Overrides the calendar-color." : "Warna spesial dari acara ini. Mengganti warna kalender.",
    "Chat room for event" : "Ruang obrolan untuk acara",
    "Review" : "Tinjauan",
    "Mail" : "Email",
    "Birthday" : "Tanggal lahir"
},
"nplurals=1; plural=0;");
